ECIS Data Processing
=====================

.. code-block::

    usage: ecis-processing [-h] [-o OUTPUT] DIRECTORY

    Process diagnosis and medication data.

    positional arguments:
      DIRECTORY             path to input directory

    optional arguments:
      -h, --help            show this help message and exit
      -o OUTPUT, --output OUTPUT
                            output file name, defaults to 'processed.csv'


